Talks & Tutorials
=================

.. raw:: html

   <iframe width="560"
           height="315"
           src="https://www.youtube.com/embed/nnndxbr_Xq4"
           style="margin: 0 auto 20px auto; display: block;"
           frameborder="0"
           allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture"
           allowfullscreen></iframe>

Dask Tutorial
-------------
`Dask Tutorial <https://tutorial.dask.org>`__ provides an overview of Dask and is typically delivered in 3 hours.
See `Parallel and Distributed Computing in Python with Dask <https://www.youtube.com/watch?v=EybGGLbLipI>`__ for the
latest Dask Tutorial recording from SciPy 2020.

Dask Slides
-----------
`Dask Slides <https://dask.org/slides>`__ provide a quick overview of the motivation for Dask.

Dask YouTube channel
--------------------
You can find lots of videos about Dask on the `Dask YouTube channel <https://www.youtube.com/c/dask-dev>`__

.. contents:: :local:

Presentations
-------------

* Dask Summit 2021

  * `Keynotes <https://www.youtube.com/playlist?list=PLJ0vO2F_f6OBymP5LtgOC6W4pxd9Mw3cE>`__ 
  * `Workshops and Tutorials <https://www.youtube.com/playlist?list=PLJ0vO2F_f6OBD1_iNeT1f7cpRoYwAuMPy>`__
  * `Talks <https://www.youtube.com/playlist?list=PLJ0vO2F_f6OBcisTDubrdEsQAhigkayjE>`__

* PyCon US 2021

  * `Tutorial: Hacking Dask: Diving into Dask's Internals <https://www.youtube.com/watch?v=LQrgDhN-XOo>`__  (`materials <https://github.com/jrbourbeau/hacking-dask>`__)
  * `Dask-SQL: Empowering Pythonistas for Scalable End-to-End Data Engineering <https://www.youtube.com/watch?v=z7xKikaScxg>`__


* BlazingSQL Webinars, May 2021

  * `Intro to distributed computing on GPUs with Dask in Python <https://www.youtube.com/watch?v=py1YPs6s6so>`__ (`materials <https://gist.github.com/jacobtomlinson/6f16abb716f50f81a6687bd67efd2f61>`__)

* PyData DC, August 2021

  * `Inside Dask <https://www.youtube.com/watch?v=X95WO41abXo>`__ (`materials <https://github.com/jsignell/inside-dask>`__)

* PyCon US 2020

  * `Deploying Python at Scale with Dask <https://www.youtube.com/watch?v=deX0GlW4uew>`__

* PyCon Australia 2020

  * `dask-image: distributed image processing for large data <https://www.youtube.com/watch?v=MpjgzNeISeI>`__

* PyCon Korea 2019, August 2019

  * `Adapting from Spark to Dask: what to expect (18 minutes)
    <https://www.youtube.com/watch?v=tx7qTHSlHKw>`__

* SciPy 2019, July 2019

  * `Refactoring the SciPy Ecosystem for Heterogeneous Computing (29 minutes)
    <https://www.youtube.com/watch?v=Q0DsdiY-jiw>`__
  * `Renewable Power Forecast Generation with Dask & Visualization with Bokeh (31 minutes)
    <https://www.youtube.com/watch?v=tYGcicSruck>`__
  * `Efficient Atmospheric Analogue Selection with Xarray and Dask (18 minutes)
    <https://www.youtube.com/watch?v=gdHiGsGUh3o>`__
  * `Better and Faster Hyper Parameter Optimization with Dask (27 minutes)
    <https://www.youtube.com/watch?v=x67K9FiPFBQ>`__
  * `Dask image:A Library for Distributed Image Processing (22 minutes)
    <https://www.youtube.com/watch?v=XGUS174vvLs>`__

* EuroPython 2019, July 2019

  * `Distributed Multi-GPU Computing with Dask, CuPy and RAPIDS (29 minutes)
    <https://www.youtube.com/watch?v=en2zdTT-Vwk>`__

* SciPy 2018, July 2018

  * `Scalable Machine Learning with Dask (30 minutes)
    <https://www.youtube.com/watch?v=ccfsbuqsjgI>`__

* PyCon 2018, May 2018

  * `Democratizing Distributed Computing with Dask and JupyterHub (32 minutes)
    <https://www.youtube.com/watch?v=Iq72dt1gO9c>`__

* AMS & ESIP, January 2018

  * `Pangeo quick demo: Dask, XArray, Zarr on the cloud with JupyterHub (3 minutes)
    <https://www.youtube.com/watch?v=rSOJKbfNBNk>`__
  * `Pangeo talk: An open-source big data science platform with Dask, XArray, Zarr on the cloud with JupyterHub (43 minutes)
    <https://www.youtube.com/watch?v=mDrjGxaXQT4>`__

* PYCON.DE 2017, November 2017

  * `Dask: Parallelism in Python (1 hour, 2 minutes)
    <https://www.youtube.com/watch?v=rZlshXJydgQ>`__

* PYCON 2017, May 2017

  * `Dask: A Pythonic Distributed Data Science Framework (46 minutes)
    <https://www.youtube.com/watch?v=RA_2qdipVng>`__

* PLOTCON 2016, December 2016

  * `Visualizing Distributed Computations with Dask and Bokeh (33 minutes)
    <https://www.youtube.com/watch?v=FTJwDeXkggU>`__

* PyData DC, October 2016

  * `Using Dask for Parallel Computing in Python (44 minutes)
    <https://www.youtube.com/watch?v=s4ChP7tc3tA>`__

* SciPy 2016, July 2016

  * `Dask Parallel and Distributed Computing (28 minutes)
    <https://www.youtube.com/watch?v=PAGjm4BMKlk>`__

* PyData NYC, December 2015

  * `Dask Parallelizing NumPy and Pandas through Task Scheduling (33 minutes)
    <https://www.youtube.com/watch?v=mHd8AI8GQhQ>`__

* PyData Seattle, August 2015

  * `Dask: out of core arrays with task scheduling (1 hour, 50 minutes)
    <https://www.youtube.com/watch?v=ieW3G7ZzRZ0>`__

* SciPy 2015, July 2015

  * `Dask Out of core NumPy:Pandas through Task Scheduling (16 minutes)
    <https://www.youtube.com/watch?v=1kkFZ4P-XHg>`__
